@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 import numpy as np
-
+from numpy import linalg as LA
 
 def stability_test(matrix, crystal_type):
 
@@ -47,7 +47,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
         return stable
 
@@ -85,7 +85,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
     if crystal_type == "tetragonal":
         print("Tetragonal crystal system \n")
@@ -136,7 +136,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
     if crystal_type == "rhombohedral-1":
         print("Rhombohedral (class-1): point group: 3m, -3m and 32 \n")
@@ -177,7 +177,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
     if crystal_type == "rhombohedral-2":
         print("Rhombohedral (class-2): i.e structures with point group: 3, -3 \n")
@@ -220,7 +220,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
     if crystal_type == "orthorhombic":
         print("Orthorhombic crystal system.... \n")
@@ -292,7 +292,7 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
     if crystal_type == "monoclinic":
         print("Monoclinic crystal system.... \n")
@@ -452,20 +452,60 @@ def stability_test(matrix, crystal_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
+
+
+
+    if crystal_type == "triclinic":
+        print("Triclinic crystal system.... \n")
+        print(
+            "Triclinic systems only criteria for stability are positive eigen values of the elastic tensor  \n"
+        )
+        evals = list(LA.eigvals(c))
+        evalsPrint = list(np.around(np.array(evals), 3))
+        print("%s" % evalsPrint)
+        check = 0
+        for i in range(len(evals)):
+            if evals[i] > 0.0:
+                stable = True
+                pass
+            else:
+                check = 1
+                stable = False
+
+
+
 
     return stable
 
 
+
+
+
+
+
 def stability_test_2d(matrix, lattice_type):
-    c = np.copy(matrix)
+    c = np.zeroz(shape = (3,3))
+    
+    c[0,0] = matrix[0,0]
+    c[0,1] = matrix[0,1]
+    c[0,2] = matrix[0,6]
+    
+    c[1,0] = matrix[1,0]
+    c[1,1] = matrix[1,1]
+    c[1,2] = matrix[1,6]
+    
+    c[2,0] = matrix[6,0]
+    c[2,1] = matrix[6,1]
+    c[2,2] = matrix[6,6]
+    
     stable = True
     if lattice_type == "hexagonal":
         print("Hexagonal lattice \n")
         print("Stability criteria for the stability of hexagonal system are: \n")
         print("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  \n ")
 
-        if c[0][0] - c[0][1] > 0.0:
+        if c[0][0] + c[0][1] > 0.0:
             print("Condition (i) satified.")
             condition1 = True
         else:
@@ -483,7 +523,7 @@ def stability_test_2d(matrix, lattice_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
         return stable
 
@@ -492,7 +532,7 @@ def stability_test_2d(matrix, lattice_type):
         print("Stability criteria for the stability of square system are: \n")
         print("(i) C11 + C12 > 0;    (ii) C11 - C12 > 0;  (iii) C33 > 0     \n ")
 
-        if c[0][0] - c[0][1] > 0.0:
+        if c[0][0] + c[0][1] > 0.0:
             print("Condition (i) satified.")
             condition1 = True
         else:
@@ -506,7 +546,7 @@ def stability_test_2d(matrix, lattice_type):
             print("Condition (ii) NOT satisfied.")
             condition2 = False
 
-        if c[2][5] > 0.0:
+        if c[2][2] > 0.0:
             print("Condition (iii) satified.")
             condition3 = True
         else:
@@ -517,7 +557,7 @@ def stability_test_2d(matrix, lattice_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
         return stable
 
@@ -571,7 +611,7 @@ def stability_test_2d(matrix, lattice_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
         return stable
 
@@ -605,6 +645,6 @@ def stability_test_2d(matrix, lattice_type):
 
         for condition in conditions:
             if condition == False:
-                stable == False
+                stable = False
 
         return stable
